@@ -1,5 +1,5 @@
 package WebService::Gitter;
-$WebService::Gitter::VERSION = '2.1.1';
+$WebService::Gitter::VERSION = '2.2.0';
 #ABSTRACT: An interface to Gitter REST API via Perl 5.
 
 use strict;
@@ -126,10 +126,27 @@ method unread_items( $user_id, $room_id ) {
           . $self->api_key );
 }
 
+method mark_unread_items( $user_id, $room_id, @chat_ids ) {
+    return $self->post(
+        "/user/$user_id/rooms/$room_id/unreadItems?access_token="
+          . $self->api_key,
+        { chat => @chat_ids }
+    );
+}
+
 method orgs($user_id) {
     return $self->get( "/user/$user_id/orgs?access_token=" . $self->api_key );
 }
 
+method repos($user_id) {
+    return $self->get( "/user/$user_id/repos?access_token=" . $self->api_key );
+}
+
+method channels($user_id) {
+    return $self->get(
+        "/user/$user_id/channels?access_token=" . $self->api_key );
+}
+
 1;
 
 =pod
@@ -142,7 +159,7 @@ WebService::Gitter - An interface to Gitter REST API via Perl 5.
 
 =head1 VERSION
 
-version 2.1.1
+version 2.2.0
 
 =head1 SYNOPSIS
 
@@ -199,6 +216,18 @@ version 2.1.1
     # Retrieve unread items and mentions from a room.
     $git->unread_items($user_id, $room_id);
 
+    # Use to mark chat messages as read.
+    $git->mark_unread_items($user_id, $room_id, @chat_ids);
+
+    # List of the user's GitHub Repositories and their respective Room if available.
+    $git->orgs($user_id);
+
+    # List of the user's GitHub Repositories and their respective Room if available.
+    $git->repos($user_id);
+
+    # List of Gitter channels nested under the current user.
+    $git->channels($user_id);
+
 =begin html
 
 <p>
@@ -388,12 +417,46 @@ Parameter: B<REQUIRED> C<$room_id> - Room ID.
 
 Returns: Unread items response.
 
+=item C<mark_unread_items($user_id, $room_id, @chat_ids)>
+
+Description: Mark chat messages as read.
+
+Parameter: B<REQUIRED> C<$user_id> - User ID.
+
+Parameter: B<REQUIRED> C<$room_id> - Room ID.
+
+Parameter: B<REQUIRED> C<@chat_ids> - List of chat ids to mark as read.
+
+Returns: Marked chat_ids/items response.
+
 =item C<orgs($user_id)>
 
+Description: List of the user's GitHub Repositories and their respective Room if available.
+
+B<Note>: It'll return private repositories if the current user has granted Gitter privileges to access them.
+
 Parameter: B<REQUIRED> C<$user_id> - User ID.
 
 Returns: User's organizations response.
 
+=item C<repos($user_id)>
+
+Description: List of the user's GitHub Repositories and their respective Room if available.
+
+B<Note>: It'll return private repositories if the current user has granted Gitter privileges to access them.
+
+Parameter: B<REQUIRED> C<$user_id> - User ID.
+
+Returns: User's repositories list data response.
+
+=item C<channels($user_id)>
+
+Description: List of Gitter channels nested under the current user.
+
+Parameter: B<REQUIRED> C<$user_id> - User ID.
+
+Returns: User's channel list response.
+
 =back
 
 =head1 SEE ALSO
